@@ -53,7 +53,7 @@ impl DisplayNameAndId {
         } else {
         }
 
-        self.get_block_name(&p.parent().expect("/index/index/index?"))
+        self.get_block_name(p.parent().expect("/index/index/index?"))
     }
 
     fn get_display_name(&mut self, _: &Expr) -> JsWord {
@@ -63,7 +63,7 @@ impl DisplayNameAndId {
             FileName::Real(f) if self.config.file_name => {
                 let block_name = self.get_block_name(f);
 
-                if block_name == &*component_name {
+                if block_name == *component_name {
                     return component_name;
                 }
 
@@ -141,9 +141,8 @@ impl DisplayNameAndId {
         get_existing_config(e, |e| {
             if let Expr::Call(CallExpr { args, .. }) = e {
                 if let Some(Expr::Object(existing_config)) = args.get_mut(0).map(|v| &mut *v.expr) {
-                    if !already_has(&existing_config) {
+                    if !already_has(existing_config) {
                         existing_config.props.extend(with_config_props.take());
-                        return;
                     }
                 }
             }
@@ -240,12 +239,8 @@ impl VisitMut for DisplayNameAndId {
     fn visit_mut_class_prop(&mut self, e: &mut ClassProp) {
         let old = self.cur_display_name.take();
 
-        match &e.key {
-            PropName::Ident(i) => {
-                self.cur_display_name = Some(i.sym.clone());
-            }
-
-            _ => {}
+        if let PropName::Ident(i) = &e.key {
+            self.cur_display_name = Some(i.sym.clone());
         }
 
         e.visit_mut_children_with(self);
@@ -267,22 +262,22 @@ impl VisitMut for DisplayNameAndId {
                 (
                     // styled()
                     self.state.borrow().is_styled(&*callee)
-                        && get_property_as_ident(&callee)
+                        && get_property_as_ident(callee)
                             .map(|v| v == "withConfig")
                             .unwrap_or(false)
                 ) || (
                     // styled(x)({})
                     self.state.borrow().is_styled(&*callee)
-                        && !get_callee(&callee)
+                        && !get_callee(callee)
                             .map(|callee| callee.is_member())
                             .unwrap_or(false)
                 ) || (
                     // styled(x).attrs()({})
                     self.state.borrow().is_styled(callee)
-                        && get_callee(&callee)
+                        && get_callee(callee)
                             .map(|callee| {
                                 callee.is_member()
-                                    && get_property_as_ident(&callee)
+                                    && get_property_as_ident(callee)
                                         .map(|v| v == "withConfig")
                                         .unwrap_or(false)
                             })
@@ -290,19 +285,19 @@ impl VisitMut for DisplayNameAndId {
                 ) || (
                     // styled(x).withConfig({})
                     self.state.borrow().is_styled(&*callee)
-                        && get_callee(&callee)
+                        && get_callee(callee)
                             .map(|callee| {
                                 callee.is_member()
-                                    && get_property_as_ident(&callee)
+                                    && get_property_as_ident(callee)
                                         .map(|v| v == "withConfig")
                                         .unwrap_or(false)
-                                    && args.len() > 0
+                                    && !args.is_empty()
                                     && args[0].spread.is_none()
                                     && match &*args[0].expr {
                                         Expr::Object(first_arg) => {
                                             !first_arg.props.iter().any(|prop| match prop {
                                                 PropOrSpread::Prop(prop) => {
-                                                    match get_prop_name(&prop) {
+                                                    match get_prop_name(prop) {
                                                         Some(PropName::Ident(prop_name)) => {
                                                             match &*prop_name.sym {
                                                                 "componentId" | "displayName" => {
@@ -338,7 +333,7 @@ impl VisitMut for DisplayNameAndId {
         };
 
         let display_name = if self.config.display_name {
-            Some(self.get_display_name(&expr))
+            Some(self.get_display_name(expr))
         } else {
             None
         };
@@ -363,11 +358,8 @@ impl VisitMut for DisplayNameAndId {
     fn visit_mut_key_value_prop(&mut self, e: &mut KeyValueProp) {
         let old = self.cur_display_name.take();
 
-        match &e.key {
-            PropName::Ident(name) => {
-                self.cur_display_name = Some(name.sym.clone());
-            }
-            _ => {}
+        if let PropName::Ident(name) = &e.key {
+            self.cur_display_name = Some(name.sym.clone());
         }
 
         e.visit_mut_children_with(self);
@@ -378,11 +370,8 @@ impl VisitMut for DisplayNameAndId {
     fn visit_mut_var_declarator(&mut self, v: &mut VarDeclarator) {
         let old = self.cur_display_name.take();
 
-        match &v.name {
-            Pat::Ident(name) => {
-                self.cur_display_name = Some(name.id.sym.clone());
-            }
-            _ => {}
+        if let Pat::Ident(name) = &v.name {
+            self.cur_display_name = Some(name.id.sym.clone());
         }
 
         v.visit_mut_children_with(self);
@@ -396,18 +385,18 @@ fn get_callee(e: &Expr) -> Option<&Expr> {
         Expr::Call(CallExpr {
             callee: Callee::Expr(callee),
             ..
-        }) => Some(&callee),
+        }) => Some(callee),
         _ => None,
     }
 }
 
 fn get_property_as_ident(e: &Expr) -> Option<&JsWord> {
-    match e {
-        Expr::Member(MemberExpr {
-            prop: MemberProp::Ident(p),
-            ..
-        }) => return Some(&p.sym),
-        _ => {}
+    if let Expr::Member(MemberExpr {
+        prop: MemberProp::Ident(p),
+        ..
+    }) = e
+    {
+        return Some(&p.sym);
     }
 
     None
@@ -431,57 +420,48 @@ fn get_existing_config<F>(e: &mut Expr, op: F)
 where
     F: FnOnce(&mut Expr),
 {
-    match e {
-        Expr::Call(CallExpr {
-            callee: Callee::Expr(callee),
+    if let Expr::Call(CallExpr {
+        callee: Callee::Expr(callee),
+        ..
+    }) = e
+    {
+        if let Expr::Call(CallExpr {
+            callee: Callee::Expr(callee_callee),
             ..
-        }) => match &mut **callee {
-            Expr::Call(CallExpr {
-                callee: Callee::Expr(callee_callee),
+        }) = &mut **callee
+        {
+            if let Expr::Member(MemberExpr {
+                prop: MemberProp::Ident(prop),
                 ..
-            }) => {
-                match &**callee_callee {
-                    Expr::Member(MemberExpr {
-                        prop: MemberProp::Ident(prop),
-                        ..
-                    }) => {
-                        if &*prop.sym == "withConfig" {
-                            return op(callee);
-                        }
-                    }
-                    _ => {}
-                }
-
-                match &mut **callee_callee {
-                    Expr::Member(MemberExpr {
-                        obj,
-                        prop: MemberProp::Ident(..),
-                        ..
-                    }) => match &**obj {
-                        Expr::Call(CallExpr {
-                            callee: Callee::Expr(callee),
-                            ..
-                        }) => match &**callee {
-                            Expr::Member(MemberExpr {
-                                prop: MemberProp::Ident(prop),
-                                ..
-                            }) => {
-                                if &*prop.sym == "withConfig" {
-                                    return op(obj);
-                                }
-                            }
-
-                            _ => {}
-                        },
-                        _ => {}
-                    },
-
-                    _ => {}
+            }) = &**callee_callee
+            {
+                if &*prop.sym == "withConfig" {
+                    return op(callee);
                 }
             }
 
-            _ => {}
-        },
-        _ => {}
+            if let Expr::Member(MemberExpr {
+                obj,
+                prop: MemberProp::Ident(..),
+                ..
+            }) = &mut **callee_callee
+            {
+                if let Expr::Call(CallExpr {
+                    callee: Callee::Expr(callee),
+                    ..
+                }) = &**obj
+                {
+                    if let Expr::Member(MemberExpr {
+                        prop: MemberProp::Ident(prop),
+                        ..
+                    }) = &**callee
+                    {
+                        if &*prop.sym == "withConfig" {
+                            op(obj)
+                        }
+                    }
+                }
+            }
+        }
     }
 }
