@@ -45,6 +45,7 @@ impl TranspileCssProp {
         *idx += 1;
         *idx
     }
+    #[allow(clippy::wrong_self_convention)]
     fn is_top_level_ident(&mut self, ident: &Ident) -> bool {
         self.top_level_decls
             .as_ref()
@@ -93,7 +94,7 @@ impl VisitMut for TranspileCssProp {
                                 callee: import_name.as_callee(),
                                 args: vec![Lit::Str(Str {
                                     span: DUMMY_SP,
-                                    value: name.sym.into(),
+                                    value: name.sym,
                                     raw: None,
                                 })
                                 .as_arg()],
@@ -364,28 +365,24 @@ impl VisitMut for TranspileCssProp {
         }
 
         let mut serialized_body: Vec<ModuleItem> = vec![];
-        let body = std::mem::replace(&mut n.body, vec![]);
+        let body = std::mem::take(&mut n.body);
         for item in body {
             serialized_body.push(item.clone());
-            match &item {
-                ModuleItem::Stmt(Stmt::Decl(Decl::Var(vd))) => {
-                    for decl in &vd.decls {
-                        if let Pat::Ident(ident) = &decl.name {
-                            let id = ident.to_id();
-                            let stmts = self.interleaved_injections.remove(&id);
-                            if let Some(stmts) = stmts {
-                                serialized_body
-                                    .extend(stmts.into_iter().rev().map(ModuleItem::Stmt));
-                            }
+            if let ModuleItem::Stmt(Stmt::Decl(Decl::Var(vd))) = &item {
+                for decl in &vd.decls {
+                    if let Pat::Ident(ident) = &decl.name {
+                        let id = ident.to_id();
+                        let stmts = self.interleaved_injections.remove(&id);
+                        if let Some(stmts) = stmts {
+                            serialized_body.extend(stmts.into_iter().rev().map(ModuleItem::Stmt));
                         }
                     }
                 }
-                _ => {}
             }
         }
         n.body = serialized_body;
 
-        let mut remaining = std::mem::replace(&mut self.interleaved_injections, Default::default())
+        let mut remaining = std::mem::take(&mut self.interleaved_injections)
             .into_iter()
             .collect::<Vec<_>>();
         remaining.sort_by_key(|x| x.0.clone());
@@ -450,7 +447,7 @@ impl PropertyReducer<'_> {
                 } else {
                     self.replace_object_with_prop_function = true;
 
-                    let identifier = get_local_identifier(&mut self.identifier_idx, &prop.expr);
+                    let identifier = get_local_identifier(self.identifier_idx, &prop.expr);
 
                     self.extra_attrs.push(JSXAttrOrSpread::JSXAttr(JSXAttr {
                         span: DUMMY_SP,
@@ -467,7 +464,7 @@ impl PropertyReducer<'_> {
                 acc.push(property);
             }
             PropOrSpread::Prop(ref mut prop) => {
-                let key = get_prop_key_as_expr(&prop);
+                let key = get_prop_key_as_expr(prop);
                 let key_pn = get_prop_name(prop);
 
                 if key.is_member()
@@ -479,7 +476,7 @@ impl PropertyReducer<'_> {
                 {
                     self.replace_object_with_prop_function = true;
 
-                    let identifier = get_local_identifier(&mut self.identifier_idx, &key);
+                    let identifier = get_local_identifier(self.identifier_idx, &key);
 
                     self.extra_attrs.push(JSXAttrOrSpread::JSXAttr(JSXAttr {
                         span: DUMMY_SP,
@@ -510,7 +507,7 @@ impl PropertyReducer<'_> {
 
                     self.replace_object_with_prop_function = true;
 
-                    let identifier = get_local_identifier(&mut self.identifier_idx, &value);
+                    let identifier = get_local_identifier(self.identifier_idx, &value);
 
                     self.extra_attrs.push(JSXAttrOrSpread::JSXAttr(JSXAttr {
                         span: DUMMY_SP,
@@ -521,7 +518,7 @@ impl PropertyReducer<'_> {
                         })),
                     }));
 
-                    let key = get_prop_name2(&prop);
+                    let key = get_prop_name2(prop);
 
                     acc.push(PropOrSpread::Prop(Box::new(Prop::KeyValue(KeyValueProp {
                         key,
