@@ -1,2 +1,2 @@
-import styled from "styled-components";
+import styled from 'styled-components';
 const Test = styled.div`width: 100%;`;
